# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project uses [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

[//]: # (Possible headings in a release:)
[//]: # (Highlights for shiny new features.)
[//]: # (Added for new features.)
[//]: # (Changed for changes in existing functionality.)
[//]: # (Refactor when functionality does not change but moves.)
[//]: # (Documentation for updates to docs.)
[//]: # (Testing for updates to tests.)
[//]: # (Deprecated for soon-to-be removed features.)
[//]: # (Removed for now removed features.)
[//]: # (Bugs for any known issues, especially in use before 1.0.)
[//]: # (Fixed for any bug fixes.)
[//]: # (Security in case of vulnerabilities.)
[//]: # (New contributors for first contributions.)

[//]: # (And of course if a version needs to be YANKED:)
[//]: # (## [version number] [data] [YANKED])


## [Unreleased]

### Added

- v0.2.0 will import the C code from original SLURP, but won't link it yet.
- v0.3.0 will add a very simple seed snake.
- v0.4.0 will link C code into Python and run with the simple seed snake. 
- v0.5.0 will make the seed snake editable.
- v0.6.0 will add a simple heuristic config for selecting the frame to base the
  seed snake on.
- V1.0 will be released after documentation is updated and functionality has
  been integration tested.


## [0.1.1] - 2026-03-22

### Highlights

- Initial release to reserve package name on pypi.

### Added

- Release automation for main releases to pypi.


## [0.1.0-alpha.1] - 2026-03-22

### Highlights

- Initial release to reserve package name on test.pypi.

### Added

- A lot of auxiliary files but no actual code yet.
